import math

from OpenGL import GL

import sprite
import data


rotation_speed = 2.57 #rads/sec
acceleration_speed = 6.5 #units/sec^2
slowdown_rate = 0.3 #exponent factor

class Ship:
	def __init__(self, position = [0,0], direction = 0):
		self.ship_sprite = sprite.SpriteImage.getSpriteImage(data.filepath("ship.png"))
		#updated every once in a while
		self.position = position #vector
		self.direction = direction #radians
		self.velocity = [0,0] #vector
		
		#updated from/to server upon changed
		self.keys_pressed = [False, False, False, False] #ASDW or [left,down,right,up]
	
	def draw(self):
		GL.glPushMatrix()
		GL.glTranslatef(self.position[0],self.position[1],0)
		
		GL.glRotatef((180/math.pi)*self.direction+90, 0,0,1)
		
		sprite.set_color([1,1,1,1])
		GL.glTranslatef(-0.5,-0.5,0)
		GL.glScalef(1.0/32,1.0/32,1)
		
		GL.glEnable(GL.GL_BLEND)
		GL.glBlendFunc(GL.GL_SRC_ALPHA,GL.GL_ONE_MINUS_SRC_ALPHA)
		self.ship_sprite.draw()
		
		GL.glPopMatrix()
	
	def do_frame(self, time_passed):
		self.position[0] += self.velocity[0] * time_passed
		self.position[1] += self.velocity[1] * time_passed
		
		if self.keys_pressed[0]:
			self.direction -= rotation_speed * time_passed
		if self.keys_pressed[2]:
			self.direction += rotation_speed * time_passed
		
		to_accel=0
		if self.keys_pressed[1]:
			to_accel -= 1
		if self.keys_pressed[3]:
			to_accel += 1
		if 0 != to_accel:
			to_accel *= time_passed * acceleration_speed
			self.velocity[0] += math.cos(self.direction) * to_accel
			self.velocity[1] += math.sin(self.direction) * to_accel
		
		slow_down = math.exp(time_passed * slowdown_rate)
		self.velocity[0] *= slow_down
		self.velocity[1] *= slow_down
